@@ -4,15 +4,29 @@ from notecoin.huobi.connection.restapi_sync_client import RestApiSyncClient
 from notecoin.huobi.connection.subscribe_client import SubscribeClient
 from notecoin.huobi.connection.websocket_req_client import WebSocketReqClient
 from notecoin.huobi.constant.system import HttpMethod
-from notecoin.huobi.model.market import PriceDepth, Trade, MarketDetail, MbpReq, PriceDepthReq, TradeDetailReq, \
-    TradeDetail, CandlestickEvent, Candlestick, MarketDetailEvent, MbpFullEvent, CandlestickReq, MarketDetailReq, \
-    MbpIncreaseEvent, MarketDetailMerged, MarketTicker, PriceDepthBboEvent, PriceDepthBbo, PriceDepthEvent, \
-    TradeDetailEvent
-from notecoin.huobi.utils.channels import request_mbp_channel, kline_channel, market_detail_channel, mbp_full_channel, \
-    mbp_increase_channel, price_depth_bbo_channel, price_depth_channel, trade_detail_channel
-from notecoin.huobi.utils.channels_request import request_kline_channel, request_market_detail_channel, \
-    request_price_depth_channel, request_trade_detail_channel
-from notecoin.huobi.utils.json_parser import default_parse_list_dict, default_parse, default_parse_fill_directly
+from notecoin.huobi.model.market import (Candlestick, CandlestickEvent,
+                                         CandlestickReq, MarketDetail,
+                                         MarketDetailEvent, MarketDetailMerged,
+                                         MarketDetailReq, MarketTicker,
+                                         MbpFullEvent, MbpIncreaseEvent,
+                                         MbpReq, PriceDepth, PriceDepthBbo,
+                                         PriceDepthBboEvent, PriceDepthEvent,
+                                         PriceDepthReq, Trade, TradeDetail,
+                                         TradeDetailEvent, TradeDetailReq)
+from notecoin.huobi.utils.channels import (kline_channel,
+                                           market_detail_channel,
+                                           mbp_full_channel,
+                                           mbp_increase_channel,
+                                           price_depth_bbo_channel,
+                                           price_depth_channel,
+                                           request_mbp_channel,
+                                           trade_detail_channel)
+from notecoin.huobi.utils.channels_request import (
+    request_kline_channel, request_market_detail_channel,
+    request_price_depth_channel, request_trade_detail_channel)
+from notecoin.huobi.utils.json_parser import (default_parse,
+                                              default_parse_fill_directly,
+                                              default_parse_list_dict)
 
 
 class MarketService(RestApiSyncClient):
@@ -65,7 +79,7 @@ class MarketService(RestApiSyncClient):
 
         return self.request_process(HttpMethod.GET, channel, params, parse)
 
-    def GetMarketTickersService(self, params):
+    def get_market_tickers_service(self, params):
         channel = "/market/tickers"
 
         def parse(dict_data):
@@ -73,7 +87,7 @@ class MarketService(RestApiSyncClient):
 
         return self.request_process(HttpMethod.GET, channel, params, parse)
 
-    def GetMarketTradeService(self, params):
+    def get_market_trade_service(self, params):
         channel = "/market/trade"
 
         def parse(dict_data):
@@ -83,7 +97,7 @@ class MarketService(RestApiSyncClient):
 
         return self.request_process(HttpMethod.GET, channel, params, parse)
 
-    def GetPriceDepthService(self, params):
+    def get_price_depth_service(self, params):
         channel = "/market/depth"
 
         def parse(dict_data):
@@ -97,7 +111,7 @@ class MarketServiceSocket(WebSocketReqClient):
     def __init__(self, *args, **kwargs):
         super(MarketServiceSocket, self).__init__(*args, **kwargs)
 
-    def ReqCandleStickService(self, callback, error_handler, params):
+    def req_candle_stick_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
         interval = params["interval"]
         from_ts_second = params.get("from_ts_second", None)
@@ -116,7 +130,7 @@ class MarketServiceSocket(WebSocketReqClient):
                                   callback,
                                   error_handler)
 
-    def ReqMarketDetailService(self, callback, error_handler, params):
+    def req_market_detail_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
 
         def subscription(connection):
@@ -132,7 +146,7 @@ class MarketServiceSocket(WebSocketReqClient):
                                   callback,
                                   error_handler)
 
-    def ReqMbpService(self, callback, error_handler, params):
+    def req_mbp_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
         level = params["levels"]
 
@@ -149,7 +163,7 @@ class MarketServiceSocket(WebSocketReqClient):
                                    callback,
                                    error_handler)
 
-    def ReqPriceDepthService(self, callback, error_handler, params):
+    def req_price_depth_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
         step = params["step"]
 
@@ -172,7 +186,7 @@ class MarketServiceSocket(WebSocketReqClient):
                                   callback,
                                   error_handler)
 
-    def ReqTradeDetailService(self, callback, error_handler, params):
+    def req_trade_detail_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
 
         def subscription(connection):
@@ -189,11 +203,11 @@ class MarketServiceSocket(WebSocketReqClient):
                                   error_handler)
 
 
-class MarketSeriveSub(SubscribeClient):
+class MarketServiceSub(SubscribeClient):
     def __init__(self, *args, **kwargs):
-        super(MarketSeriveSub, self).__init__(*args, **kwargs)
+        super(MarketServiceSub, self).__init__(*args, **kwargs)
 
-    def SubCandleStickService(self, callback, error_handler, params):
+    def sub_candle_stick_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
         interval = params["interval"]
 
@@ -210,7 +224,7 @@ class MarketSeriveSub(SubscribeClient):
                                   callback,
                                   error_handler)
 
-    def SubMarketDetailService(self, callback, error_handler, params):
+    def sub_market_detail_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
 
         def subscription(connection):
@@ -226,7 +240,7 @@ class MarketSeriveSub(SubscribeClient):
                                   callback,
                                   error_handler)
 
-    def SubMbpFullService(self, callback, error_handler, params):
+    def sub_mbp_full_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
         level = params["levels"]
 
@@ -243,7 +257,7 @@ class MarketSeriveSub(SubscribeClient):
                                   callback,
                                   error_handler)
 
-    def SubMbpIncreaseService(self, callback, error_handler, params):
+    def sub_mbp_increase_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
         level = params["levels"]
 
@@ -260,7 +274,7 @@ class MarketSeriveSub(SubscribeClient):
                                    callback,
                                    error_handler)
 
-    def SubPriceDepthBboService(self, callback, error_handler, params):
+    def sub_price_depth_bbo_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
 
         def subscription(connection):
@@ -276,7 +290,7 @@ class MarketSeriveSub(SubscribeClient):
                                   callback,
                                   error_handler)
 
-    def SubPriceDepthService(self, callback, error_handler, params):
+    def sub_price_depth_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
         step = params["step"]
 
@@ -297,7 +311,7 @@ class MarketSeriveSub(SubscribeClient):
                                   callback,
                                   error_handler)
 
-    def SubTradeDetailService(self, callback, error_handler, params):
+    def sub_trade_detail_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
 
         def subscription(connection):
